controller_admin_comments (zotonic_mod_comment v1.0.0-rc.17)

Shows an admin screen with an overview of most recently created comments. The screen offers the option to moderate the comments or delete them entirely.

Todo

Extend documentation

Summary

Functions

event/2

is_authorized(Context)

process(Method, AcceptedCT, ProvidedCT, Context)

service_available(Context)