controller_admin_comments_settings (zotonic_mod_comment v1.0.0-rc.17)
Shows an admin settings screen where you can edit settings related to mod_comment.
Todo
Extend documentation
Shows an admin settings screen where you can edit settings related to mod_comment.
Todo
Extend documentation