mod_comment (zotonic_mod_comment v1.0.0-rc.17)

Implements a basic commenting system, enabling commenting on resources.

The module has an admin comment overview, allowing the administrator to review the comments or delete them.

To enable commenting in your site, include _comments.tpl on your resource’s page template, passing an id parameter for the resource on which you want users to be able to comment.

Accepted Events

This module handles the following notifier callbacks:

  • observe_admin_menu: Contribute module entries to the admin menu tree.
  • observe_rsc_merge: Move all comments from one resource to another using m_comment:merge.
  • observe_search_query: Return the list of recent comments using m_comment:search.

Delegate callbacks:

  • event/2 with submit messages: newcomment.

Summary

Functions

event/2

init(Context)

observe_admin_menu/3

observe_rsc_merge/2

observe_search_query/2